@@ -1,5 +1,17 @@
 package Games::Cards::Pair::Card;
 
+$Games::Cards::Pair::Card::VERSION = '0.04';
+
+=head1 NAME
+
+Games::Cards::Pair::Card - Object representation of a card.
+
+=head1 VERSION
+
+Version 0.04
+
+=cut
+
 use 5.006;
 use strict; use warnings;
 
@@ -8,25 +20,12 @@ use Mouse;
 use Mouse::Util::TypeConstraints;
 
 use overload ( '""'  => \&as_string );
-use Readonly;
 
-=head1 NAME
+my $SUITS  = { 'Clubs' => 1, 'Diamonds' => 1, 'Hearts' => 1, 'Spades' => 1 };
 
-Games::Cards::Pair::Card - Object representation of a card.
-
-=head1 VERSION
-
-Version 0.03
-
-=cut
-
-our $VERSION = '0.03';
-
-Readonly my $SUITS => { 'Clubs' => 1, 'Diamonds' => 1, 'Hearts' => 1, 'Spades' => 1 };
-
-Readonly my $VALUES => { '2'   => 1, '3'    => 1, '4'     => 1, '5'    => 1, '6'     => 1,
-                         '7'   => 1, '8'    => 1, '9'     => 1, '10'   => 1,
-                         'Ace' => 1, 'Jack' => 1, 'Queen' => 1, 'King' => 1, 'Joker' => 1 };
+my $VALUES = { '2'   => 1, '3'    => 1, '4'     => 1, '5'    => 1, '6'     => 1,
+               '7'   => 1, '8'    => 1, '9'     => 1, '10'   => 1,
+               'Ace' => 1, 'Jack' => 1, 'Queen' => 1, 'King' => 1, 'Joker' => 1 };
 
 type 'Suits'  => where { exists $SUITS->{ucfirst(lc($_))} };
 type 'Values' => where { exists $VALUES->{ucfirst(lc($_))} };
@@ -41,20 +40,17 @@ Only for internal use of Games::Cards::Pair class. Avoid using it directly.
 
 =cut
 
-around BUILDARGS => sub
-{
+around BUILDARGS => sub {
     my $orig  = shift;
     my $class = shift;
 
     if (defined($_[0]->{value}) && ($_[0]->{value} =~ /Joker/i)) {
-        croak("Attribute (suit) is NOT required for Joker.")
-            if defined $_[0]->{suit};
+        die("Attribute (suit) is NOT required for Joker.") if defined $_[0]->{suit};
     }
-    else
-    {
-        croak("Attribute (suit) is required.")
-            unless defined $_[0]->{suit};
+    else {
+        die("Attribute (suit) is required.") unless defined $_[0]->{suit};
     }
+
     return $class->$orig(@_);
 };
 
@@ -77,10 +73,8 @@ Returns 1 or 0 depending whether the two cards are same in value or one of them
 
 =cut
 
-sub equal
-{
-    my $self  = shift;
-    my $other = shift;
+sub equal {
+    my ($self, $other) = @_;
 
     return 0 unless (defined($other) && (ref($other) eq 'Games::Cards::Pair::Card'));
 
@@ -108,11 +102,10 @@ Returns the card object in readable format. This is overloaded as string context
 
 =cut
 
-sub as_string
-{
-    my $self = shift;
-    return sprintf("[%s of %s]", $self->value, $self->suit)
-        if defined $self->suit;
+sub as_string {
+    my ($self) = @_;
+
+    return sprintf("[%s of %s]", $self->value, $self->suit) if defined $self->suit;
 
     return sprintf("[%s]", $self->value);
 }
@@ -157,7 +150,7 @@ L<http://search.cpan.org/dist/Games-Cards-Pair/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 Mohammad S Anwar.
+Copyright 2012 - 2014 Mohammad S Anwar.
 
 This  program  is  free software;  you can redistribute it and/or modify it under the terms of
 either:  the  GNU  General Public License as published by the Free Software Foundation; or the
